:mod:`oujago.nlp.dependence`
============================

.. automodule:: oujago.nlp.dependence

.. autosummary::

    BaseDP
    LTPDP
    deparse


Detailed Description
--------------------


.. autoclass:: BaseDP
    :members:


.. autoclass:: LTPDP
    :members:

.. autofunction:: deparse
